@@ -730,7 +730,7 @@ class Connection:
 
         if fields is not None:
             request_params["fields"] = ",".join(fields)
-        response = self.do_get_request(self.get_pipe_url(pipe_id), **kwargs)
+        response = self.do_get_request(self.get_pipe_url(pipe_id), params=request_params, **kwargs)
         if response.status_code == 404:
             return None
         pipe_json = utils.parse_json_response(response)
