@@ -149,7 +149,11 @@ class Pipe(EntityBase):
 
         # If the size of the entities is very large, we have to use chunked encoding; otherwise we will get
         # a "connection reset" error.
-        entities_as_json = entity_json.entities_to_json(entities)
+        if type(entities) is str:
+            # The entities were already json-encoded.
+            entities_as_json = entities
+        else:
+            entities_as_json = entity_json.entities_to_json(entities)
 
         class BytesIOWithNoLength(io.BytesIO):
             def __len__(self):
